import router from './router'
import store from './store'
import {Message} from 'element-ui'
import NProgress from 'nprogress'
import 'nprogress/nprogress.css'
// auth文件主要依赖js-cookie模块,getToken,setToken,removeToken
import {getToken} from '@/utils/auth'

// 显示又上方螺旋加载提示
NProgress.configure({showSpinner: false})

// 路由白名单列表,把路由添加到这个数组中,不用登陆也可以访问
const whiteList = ['/login', '/register']

router.beforeEach((to, from, next) => {
    // 请求路由时进度条开始
    NProgress.start()
    if (getToken()) {
        // 如果用户存在令牌的情况下还请求登录页面,就让用户跳转到首页,避免重复登录的情况
        if (to.path === '/login') {
            next({path: '/entry'})
            NProgress.done()
        } else {

            if (store.state.user.studentName === '') {
                // 判断当前用户是否已拉取完user_info信息
                store.dispatch('GetInfo').then(() => {
                    next()
                }).catch(err => {
                    store.dispatch('LogOut').then(() => {
                        Message.error(err)
                        next({path: '/login'})
                    }).catch(err => {
                        next({path: '/login'})
                    })
                })
            } else {
                next()
            }
        }
    } else {
        // 没有token
        if (whiteList.indexOf(to.path) !== -1) {
            // 在免登录白名单，直接进入
            next()
        } else {
            next(`/login?redirect=${to.path}`) // 否则全部重定向到登录页
            NProgress.done()
        }
    }
})

router.afterEach(() => {
    NProgress.done()
})
